import { Button } from "@/components/ui/button";
import { ArrowRight, Shield, Users, TrendingUp } from "lucide-react";
import WebPImage from "./WebPImage";

const HeroSection = () => {
  return (
    <section className="relative bg-gradient-to-br from-background to-accent py-20 lg:py-32">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="grid grid-cols-1 lg:grid-cols-2 gap-12 items-center">
          {/* Content */}
          <div className="space-y-8">
            <div className="space-y-4">
              <h1 className="text-hero font-bold text-foreground leading-tight">
                Protect What Matters Most to 
                <span className="text-primary"> Your Family</span>
              </h1>
              <p className="text-xl text-muted-foreground leading-relaxed">
                I'm Cory Nunes, and I believe every family deserves financial security and peace of mind. 
                Let's create a personalized strategy that protects your loved ones and builds lasting wealth.
              </p>
            </div>

            {/* Value Props */}
            <div className="grid grid-cols-1 sm:grid-cols-3 gap-6">
              <div className="flex items-center space-x-3">
                <div className="bg-primary/10 p-2 rounded-lg">
                  <Shield className="h-6 w-6 text-primary" />
                </div>
                <div>
                  <h3 className="font-semibold text-foreground">Personalized Protection</h3>
                  <p className="text-sm text-muted-foreground">Tailored to your unique needs</p>
                </div>
              </div>
              
              <div className="flex items-center space-x-3">
                <div className="bg-primary/10 p-2 rounded-lg">
                  <Users className="h-6 w-6 text-primary" />
                </div>
                <div>
                  <h3 className="font-semibold text-foreground">Family First</h3>
                  <p className="text-sm text-muted-foreground">Your loved ones are protected</p>
                </div>
              </div>
              
              <div className="flex items-center space-x-3">
                <div className="bg-primary/10 p-2 rounded-lg">
                  <TrendingUp className="h-6 w-6 text-primary" />
                </div>
                <div>
                  <h3 className="font-semibold text-foreground">Wealth Building</h3>
                  <p className="text-sm text-muted-foreground">Strategic financial growth</p>
                </div>
              </div>
            </div>

            {/* CTA Buttons */}
            <div className="flex flex-col sm:flex-row gap-4">
              <Button
                variant="cta"
                size="lg"
                asChild
                className="text-lg px-8 py-4 h-14"
              >
                <a 
                  href="https://corynunes.com/general-meeting-booking-30min"
                  target="_blank"
                  rel="noopener noreferrer"
                >
                  Schedule Your Free Consultation
                  <ArrowRight className="ml-2 h-5 w-5" />
                </a>
              </Button>
              
              <Button
                variant="outline"
                size="lg"
                asChild
                className="text-lg px-8 py-4 h-14"
              >
                 <a 
                  href="#services"
                  aria-label="Learn about our insurance and financial planning services"
                >
                  Explore Our Services
                </a>
              </Button>
            </div>

            {/* Trust Indicators */}
            <div className="flex flex-col sm:flex-row items-start sm:items-center gap-4 pt-4">
              <div className="flex items-center space-x-2">
                <div className="flex -space-x-2">
                  <div className="w-8 h-8 bg-primary rounded-full border-2 border-background"></div>
                  <div className="w-8 h-8 bg-secondary rounded-full border-2 border-background"></div>
                  <div className="w-8 h-8 bg-primary rounded-full border-2 border-background"></div>
                </div>
                <p className="text-sm text-muted-foreground">
                  <span className="font-semibold text-foreground">100+ families</span> protected
                </p>
              </div>
              
              <div className="hidden sm:block w-px h-6 bg-border"></div>
              
              <p className="text-sm text-muted-foreground">
                <span className="font-semibold text-foreground">Licensed professional</span> in CA
              </p>
            </div>
          </div>

          {/* Image */}
          <div className="relative">
            <div className="relative bg-gradient-to-br from-primary/5 to-primary/10 rounded-2xl p-8 section-elegant">
              <WebPImage
                src="https://storage.googleapis.com/msgsndr/FzqSk7x9NC1bIVtPLAWF/media/6871bdc6556bb03f56aedf86.webp"
                alt="Cory Nunes - Professional insurance advisor and financial planner serving families in Northern California"
                className="w-full h-auto rounded-lg shadow-xl"
                loading="eager"
                decoding="sync"
                width={400}
                height={400}
                sizes="(max-width: 768px) 100vw, (max-width: 1024px) 50vw, 400px"
                fetchPriority="high"
              />
              
              {/* Floating elements */}
              <div className="absolute -top-4 -right-4 bg-primary text-primary-foreground px-4 py-2 rounded-lg shadow-lg">
                <p className="text-sm font-semibold">Licensed Professional</p>
              </div>
              
              <div className="absolute -bottom-4 -left-4 bg-background border border-border px-4 py-3 rounded-lg shadow-lg">
                <p className="text-sm">
                  <span className="font-semibold text-primary">15+ years</span>
                  <br />
                  <span className="text-muted-foreground">experience</span>
                </p>
              </div>
            </div>
          </div>
        </div>
      </div>
    </section>
  );
};

export default HeroSection;